<?php
/***************************************************************************
 *                                functions_forum.php
 *                            -------------------
 *   begin                : Saturday, Feb 13, 2001
 *   copyright            : (C) 2001 The phpBB Group
 *   email                : support@phpbb.com
 *
 *   $Id: functions_forum.php 433 2006-03-12 15:32:05Z mikethecoder $
 *
 *
 ***************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

/**
* Returns a list of the fora ordered by forum_id
*/
function get_fora($fora_ids = false, $ids_only = false)
{
	static $fora = array();
	if (empty($fora))
	{
		global $db;
		$sql = 'SELECT * 
			FROM ' . FORUMS_TABLE . '
			ORDER BY forum_id ASC';
		if (!($result = $db->sql_query($sql)))
		{
			message_die (GENERAL_ERROR, 'ERROR_DATABASE', '', __LINE__, __FILE__, $sql);
		}
		while ($row = $db->sql_fetchrow($result))
		{
			$fora[intval($row['forum_id'])] = $row;
		}
		$db->sql_freeresult($result);
	}
	$return = $fora;
	if ($fora_ids !== false)
	{
		if (is_integer($fora_ids) && isset($fora[$fora_ids]))
		{
			$return = $fora[$fora_ids];
		}
		elseif (is_array($fora_ids) && !empty($fora_ids))
		{
			$return = array_intersect_key($fora, array_flip($fora_ids));
		}
	}
	return (($ids_only) ? array_keys($return) : $return);
}

/**
* Returns an array of fora data which the specified auth checking
*/
function get_fora_authed($auth_type, $fora_ids = false, $ids_only = false)
{
	static $fora = array();
	static $is_auth_ary = array();

	$auth_types = array(
		AUTH_VIEW		=> 'auth_view',
		AUTH_READ		=> 'auth_read',
		AUTH_POST		=> 'auth_post',
		AUTH_REPLY		=> 'auth_reply',
		AUTH_EDIT		=> 'auth_edit',
		AUTH_DELETE		=> 'auth_delete',
		AUTH_ANNOUNCE	=> 'auth_announce',
		AUTH_GLOBALANNOUNCE	=> 'auth_globalannounce',
		AUTH_STICKY		=> 'auth_sticky',
		AUTH_POLLCREATE	=> 'auth_pollcreate',
		AUTH_VOTE		=> 'auth_vote',
		AUTH_DELAYEDPOST	=> 'auth_delayedpost',
		AUTH_ATTACH		=> 'auth_attachments',
		AUTH_DOWNLOAD	=> 'auth_download',
		AUTH_CALENDAR	=> 'auth_calendar',
	);

	if ((!is_array($fora_ids) && $fora_ids !== false) || ($auth_type != AUTH_ALL && !isset($auth_types[$auth_type])))
	{
		return false;
	}

	if (empty($fora))
	{
		global $userdata;
		$fora = get_fora();
		//@todo
		//if ($userdata['user_level'] != ADMIN)
		//{
			$is_auth_ary = auth(AUTH_ALL, AUTH_LIST_ALL, $userdata, array_values($fora)); // TODO: Check this
			foreach (array_keys($fora) as $void => $forum_id)
			{
				if (!$is_auth_ary[$forum_id]['auth_view'])
				{
					unset($fora[$forum_id]);
				}
			}
		//}
	}
	
	if ($fora_ids === false && $auth_type == AUTH_ALL)
	{
		return (($ids_only) ? array_keys($fora) : $fora);
	}
	$return = array();
	$auth_type = $auth_types[$auth_type];
	foreach (array_keys($fora) as $void => $forum_id)
	{
		if (($fora_ids === false || isset($fora_ids[$forum_id])) && ($userdata['user_level'] == ADMIN || $is_auth_ary[$forum_id][$auth_type]))
		{
			$return[$forum_id] = $fora[$forum_id];
		}
	}
	return (($ids_only) ? array_keys($return) : $return);
}

/**
* Returns a list of the categories ordered by category_id
*/
function get_categories()
{
	static $categories = array();
	if (empty($categories))
	{
		global $db;
		$sql = 'SELECT category_id 
			FROM ' . CATEGORIES_TABLE . '
			ORDER BY category_id ASC';
		if (!($result = $db->sql_query($sql)))
		{
			message_die (GENERAL_ERROR, 'ERROR_DATABASE', '', __LINE__, __FILE__, $sql);
		}
		$categories = $db->sql_fetchrowset($result);
		$db->sql_freeresult($result);
	}
	return $categories;
}

// get the depth level
function get_max_depth($cat_id)
{
	global $db;
	if ($cat_id < 0)
	{
		$cat_id = 0;
	}
	$local_depth = 0;
	$sql = 'SELECT * 
		FROM ' . CATEGORIES_TABLE . ' 
		WHERE cat_main = ' . intval($cat_id);
	if (!($result = $db->sql_query($sql)))
	{
		message_die(GENERAL_ERROR, 'Could not query categorie parm', '', __LINE__, __FILE__, $sql);
	}
	while ($row = $db->sql_fetchrow($result))
	{
		$branch_depth = get_max_depth($row['cat_id']);
		//if ($cat_id > 0)
		//{
			$branch_depth++;
		//}
		if ($branch_depth > $local_depth)
		{
			$local_depth = $branch_depth;
		}
	}
	$db->sql_freeresult($result);
	return $local_depth;
}

// build the cat list sorted
function get_auth_cat_order(&$cat_row, &$cat_list, $cat_main = 0, $level = 0)
{
	global $db;

	$rowlevel = array();
	
	// read daughter cats
	$sql = 'SELECT * 
		FROM ' . CATEGORIES_TABLE . ' 
		WHERE cat_main = ' . intval($cat_main) . ' 
		ORDER BY cat_order, cat_id';
	if (!($result = $db->sql_query($sql)))
	{
		message_die(GENERAL_ERROR, 'Could not access list of Categories', '', __LINE__, __FILE__, $sql);
	}
	while ($row = $db->sql_fetchrow($result))
	{
		$rowlevel[] = $row;
	}
	$db->sql_freeresult($result);
	$cat_list_keys = array_flip($cat_list);
	// push and get the sub- daughter cat
	for ($i = 0, $max = count($rowlevel); $i < $max; $i++)
	{
		if (isset($cat_list_keys[$rowlevel[$i]['cat_id']]))
		{
			$rowlevel[$i]['level'] = $level;
			$cat_row[] = $rowlevel[$i];
			get_auth_cat_order($cat_row, $cat_list, $rowlevel[$i]['cat_id'], ($level + 1));
		}
	}
}

// build the auth cat list
function get_auth_cat()
{
	global $db, $userdata, $forum_data;

	// get the cat id of all auth forums
	$catlist = array();
	$sql = 'SELECT * 
		FROM ' . FORUMS_TABLE;
	if (!($result = $db->sql_query($sql)))
	{
		message_die(GENERAL_ERROR, 'Could not obtain forum list.', '', __LINE__, __FILE__, $sql);
	}
	while ($row = $db->sql_fetchrow($result))
	{
		$is_auth = array();
		$is_auth = auth(AUTH_ALL, $row['forum_id'], $userdata);
		if ($is_auth['auth_view'])
		{
			$catlist[] = $row['cat_id'];
		}
	}
	$db->sql_freeresult($result);
	// get the mother cat
	$t_cat = $catlist;
	$catlist_keys = array_flip($catlist);
	while (count($t_cat) > 0)
	{
		$s_cat = implode(', ', $t_cat);
		$t_cat = array();
		$sql = 'SELECT * 
			FROM ' . CATEGORIES_TABLE . ' 
			WHERE cat_id in (' . $s_cat . ')';
		if (!($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Could not obtain category list.', '', __LINE__, __FILE__, $sql);
		}
		while ($row = $db->sql_fetchrow($result))
		{
			if (!isset($catlist_keys[$row['cat_main']]))
			{
				$catlist[] = $row['cat_main'];
				$t_cat[] =  $row['cat_main'];
			}
		}
		$db->sql_freeresult($result);
	}

	// read cat sorted
	$catrows = array();
	get_auth_cat_order($catrows, $catlist);
	return $catrows;
}
//-- add
// build the nav sentence
function make_cat_nav_tree($cat_id, $with_link)
{
	global $db,$phpEx;
	global $nav_separator, $nav_link_active;

	if ($nav_link_active) 
	{
		$with_link = true;
	}
	$this_cat = '';
	if ($cat_id > 0)
	{
		$sql = 'SELECT cat_main, cat_title 
			FROM ' . CATEGORIES_TABLE . ' 
			WHERE cat_id = ' . intval($cat_id);
		if (!($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Could not make navigation sequence', '', __LINE__, __FILE__, $sql);
		}
		if ($catw = $db->sql_fetchrow($result))
		{
			$cat_main  = $catw['cat_main'];
			$cat_title = $catw['cat_title'];
			$this_cat = ($with_link) ? '<a href="'.append_sid("forum.$phpEx?c=$cat_id").'" class="nav">'.$cat_title.'</a>' : $cat_title;
			// vérifier si un parent
			if ($cat_main != $cat_id && $cat_main > 0)
			{
				$this_cat = make_cat_nav_tree($cat_main, true) . $nav_separator . $this_cat;
			}
		}
		$db->sql_freeresult($result);
	}
	return $this_cat;
}

//
// Gets custom headers for categories
//
function get_cat_headers($cat_id)
{
	global $db;
	$custom_html = array(
		'head'	=> '',
		'foot'	=> '',
	);

	$sql = 'SELECT cat_head, cat_foot
		FROM ' . CATEGORIES_TABLE . ' 
		WHERE cat_id = ' . intval($cat_id);
	if (!($result = $db->sql_query($sql)))
	{
		message_die(GENERAL_ERROR, 'Could not obtain category headers and footers', '', __LINE__, __FILE__, $sql);
	}
	if ($catw = $db->sql_fetchrow($result))
	{
		$custom_html['head'] = $catw['cat_head'];
		$custom_html['foot'] = $catw['cat_foot'];
	}
	$db->sql_freeresult($result);
	return $custom_html;
} // end get_cat_headers

//
// build sub categories list
function get_sub_cat($cat_main, $catrow )
{
	global $db;

	if ($cat_main > 0)
	{
		// lire les rubriques dépendantes
		$sql= 'SELECT * 
			FROM ' . CATEGORIES_TABLE . ' 
			WHERE cat_id <> ' . intval($cat_main) . ' 
				AND cat_main = ' . intval($cat_main);
		if (!($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Could not get sub categories', '', __LINE__, __FILE__, $sql);
		}
		while ($catw = $db->sql_fetchrow($result))
		{
			// ajouter la catégorie
			$i = count($catrow);
			$catrow[$i] = $catw;
			// aller chercher les sous-catégories
			if ($catw['cat_id'] > 0)
			{
				$catrow = get_sub_cat($catw['cat_id'], $catrow);
			}
		}
		$db->sql_freeresult($result);
	}
	return $catrow;
}

// build sorted cats array
function get_cat($cat_id)
{
	global $db;

	$category_rows = array();
	$catrow = array();
	$cat_id = intval($cat_id);
	// vérifier la catégorie
	if ($cat_id <= 0)
	{
		$cat_id = -1;
	}
	if ($cat_id > 0)
	{
		$sql = 'SELECT * 
			FROM ' . CATEGORIES_TABLE . ' 
			WHERE cat_id = ' . $cat_id;
		if (!($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Could not query this categories', '', __LINE__, __FILE__, $sql);
		}
		if (!($row = $db->sql_fetchrow($result)))
		{
			$cat_id = -1;
		}
		$db->sql_freeresult($result);
	}
	elseif ($cat_id <= 0)
	{
		$sql = 'SELECT * 
			FROM ' . CATEGORIES_TABLE . ' 
			ORDER BY cat_order';
		if (!($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Could not query categories list', '', __LINE__, __FILE__, $sql);
		}
		while ($row = $db->sql_fetchrow($result))
		{
			$category_rows[] = $row;
		}
		$db->sql_freeresult($result);
	}
	//
	// a cat selected : get it and its sub-cats
	if ($cat_id > 0)
	{
		$catrow[] = $row;
		$catrow = get_sub_cat($cat_id, $catrow);
		$sql = 'SELECT * 
			FROM ' . CATEGORIES_TABLE . ' 
			ORDER BY cat_order';
		if (!($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Could not query categories list', '', __LINE__, __FILE__, $sql);
		}
		while ($row = $db->sql_fetchrow($result))
		{
			$found = false;
			for ($i = 0, $max = count($catrow); ($i < $max && (!$found)); $i++)
			{
				$found = ($row['cat_id'] == $catrow[$i]['cat_id']);
			}
			if ($found)
			{
				$category_rows[] = $row;
			}
		}
		$db->sql_freeresult($result);
		unset($catrow);
	}

	return $category_rows;
}
?>
