<?php
#################################################################
## Mod Title: mycalendar+ Mod w/selected forum integration
##      (based on mycalendar Mod by marksten)
## Mod Version: 0.8
## Author: flashdagger
## Description: Enables users to add events to the calendar
##              through a chosen forum.
#################################################################

/**
 * Enter/delete/modifies the event in the mycalendar table
 *
 * Depending on whether the user chooses new topic or edit post, we
 * make a modification on the mycalendar table to insert or update the event
 *
 * @param  string $mode whether we are editing or posting new topic
 * @param  int    $forum_id sql id of the forum
 * @param  int    $topic_id sql id of the topic
 * @param  int    $post_id sql id of the post
 *
 * @access private
 * @return void
 */
function mycal_submit_event($mode, $forum_id, $topic_id, $post_id, $first_post_id, &$message, &$meta)
{
    global $db, $lang, $is_auth, $HTTP_POST_VARS;

    // Do nothing for a reply
    if ($mode == 'reply' || !$is_auth['auth_calendar'] || ($mode != 'newtopic' && $mode != 'editpost')) {
        return;
    }

    $cal_data = mycal_validate_data($HTTP_POST_VARS);
    extract($cal_data, EXTR_OVERWRITE);
    $cal_isodate = (($cal_date != $lang['Date_not_specified']) ? date("YmdHi00", $ts_date) : FALSE);
    $cal_time_end = (($ts_date_end != -1) ? "$cal_hour_end:$cal_minute_end:00" : "00:00:00");

    // if this is a new topic and we can post a date to it (do we have to check this) and
    // we have specified a date, then go ahead and enter it

    if ( $mode == 'editpost' ) {
       if ($post_id != $first_post_id) return;
       $sql = "DELETE FROM " . MYCALENDAR_TABLE . " WHERE topic_id = $topic_id";
       if (!$db->sql_query($sql)) {
           message_die(GENERAL_MESSAGE, 'Could not remove event from calendar table.');
       }
    }

    if ( $cal_isodate ) {
        $sql = "INSERT INTO " . MYCALENDAR_TABLE . "(topic_id, cal_date, cal_time_end, cal_interval, cal_interval_units, cal_repeat, forum_id)
                VALUES ($topic_id, '$cal_isodate', '$cal_time_end', $cal_interval, '$cal_interval_units', $cal_repeat, $forum_id)";
            if (!$db->sql_query($sql)) {
                message_die(GENERAL_MESSAGE, 'Could not insert new event into calendar table.');
        }
        if ( $mode == 'newtopic' && (!$is_auth['auth_read'] || !$is_auth['auth_view'])) {
        global $phpEx;
        static $event_stored;
        $event_stored = TRUE;
        $meta = '<meta http-equiv="refresh" content="3;url=' . append_sid("mycalendar.$phpEx") . '">';
        $message = $lang['Suggestion_stored'] . '<br /><br />' . sprintf($lang['Click_return_calendar'], '<a href="' . append_sid("mycalendar.$phpEx") . '">', '</a>');
        }
   }
}

/**
 * Print out the event date on the page where the topic is viewed (viewtopic.php)
 *
 * This function will prepend a string to the first post in a topic
 * that declares an event date, but only if the event date has a reference
 * to a forum which allows events to be used.  In the case of a reoccuring/block date,
 * the display will be such that it explains this attribute.
 *
 * @param int  $topic_id identifier of the topic
 * @param int  $post_id identifier of the post, used to determine if this is the leading post
 * @param int  $message the message for this post, which may be altered here
 *
 * @access public
 * @return string body message
 */

function mycal_append_event($topic_id, &$message)
{
    global $db, $lang, $forum_id;
    $sql = "SELECT
                    UNIX_TIMESTAMP(c.cal_date) as cal_date,
                    c.cal_interval,
                    c.cal_interval_units,
                    c.cal_repeat,
                    UNIX_TIMESTAMP(CONCAT(DATE_FORMAT((CASE c.cal_interval_units
                WHEN 'WEEK' THEN (INTERVAL (c.cal_repeat -1) * 7 * c.cal_interval DAY + cal_date)
                WHEN 'MONTH' THEN (INTERVAL (c.cal_repeat -1) * c.cal_interval MONTH + cal_date)
                WHEN 'YEAR' THEN (INTERVAL (cal_repeat -1) * c.cal_interval YEAR + cal_date)
                ELSE (INTERVAL (cal_repeat -1) * cal_interval DAY + cal_date) END), '%Y-%m-%d '), c.cal_time_end)) as cal_date_end
           FROM
                    " . MYCALENDAR_TABLE . " as c
               WHERE
                    c.topic_id = $topic_id";

    if (!$result = $db->sql_query($sql)) {
        message_die(GENERAL_ERROR, 'Failure when looking up date entry for topic.');
    }

    // we found a calendar event, so let's append it
    if ( $db->sql_numrows($result) > 0 ) {
        $row = $db->sql_fetchrow($result);
    $times = ( $row['cal_repeat'] > 1 && ($row['cal_interval_units'] != 'DAY' || $row['cal_interval'] > 1) ) ? " (" . $row['cal_repeat'] . "x)" : "";
    $repeat = ($row['cal_interval'] != 1 || $row['cal_interval_units'] != 'DAY') ? mycal_repeattext($row['cal_interval_units'], $row['cal_interval']) . "$times<br />" : "";
    $date_entry = mycal_format_span($row['cal_date'], $row['cal_date_end']);
        $event['message'] = "<b>" . $lang['Calendar_event_title'] . ":</b> <i>$date_entry</i><br />$repeat";
        $message = "<div style=\"padding-left: 5px;\">" . $event['message'] . "</div><hr />$message";
    }
    return;
}


/**
 * Print out the selection box for selecting date
 *
 * When a new post is added or the first post in topic is edited, the poster
 * will be presented with an event date selection box if posting to an event forum
 *
 * @param  string $mode
 * @param  int $topic_id
 * @param  int $post_id
 * @param  int $forum_id
 * @param  object $template
 *
 * @access private
 * @return void
 */
function mycal_generate_entry($mode, $topic_id, $post_id, $topic_first_post_id, &$template)
{
        global $db, $lang, $is_auth, $HTTP_POST_VARS;
        // if this is a reply or not an event forum or if we are editing and it is not the first post, just return
        if ($mode == 'reply' || !$is_auth['auth_calendar'] || ($mode == 'editpost' && $post_id != $topic_first_post_id)) {
            return;
        }

    if (isset($HTTP_POST_VARS['cal_month']) && isset($HTTP_POST_VARS['cal_year'])) {
        $post_keys = array_keys($HTTP_POST_VARS);
        for ($i = 0; $i < count($post_keys); $i++)
        {
            if (substr($post_keys[$i],0,9) == "cal_date(")
            {
                sscanf($post_keys[$i], "cal_date(%[^[)]]", &$day);
                break;
            }
        }
        $format = str_replace(array('m', 'd', 'y'), array('m', 'd', 'Y'), strtolower($lang['DATE_INPUT_FORMAT']));
        $HTTP_POST_VARS['cal_date'] = date($format, mktime(0,0,0,$HTTP_POST_VARS['cal_month'],$day,$HTTP_POST_VARS['cal_year']));
        unset($post_keys);
    }


        // okay we are starting an edit on the post, let's get the required info from the tables
        if ($mode == 'editpost' && !isset($HTTP_POST_VARS['cal_date'])) {
            // setup the format used for the form
            $format = str_replace(array('m', 'd', 'y'), array('%m', '%d', '%Y'), strtolower($lang['DATE_INPUT_FORMAT']));

            // grab the event info for this topic
            $sql = "SELECT
                    DATE_FORMAT(cal_date, '$format') as cal_date,
                DATE_FORMAT((CASE cal_interval_units
                    WHEN 'DAY' THEN INTERVAL (cal_repeat - 1) * cal_interval DAY + cal_date
                    WHEN 'WEEK' THEN INTERVAL (cal_repeat - 1) * cal_interval * 7 DAY + cal_date
                    WHEN 'MONTH' THEN INTERVAL (cal_repeat - 1) * cal_interval MONTH + cal_date
                    WHEN 'YEAR' THEN INTERVAL (cal_repeat - 1) * cal_interval YEAR + cal_date
                    ELSE INTERVAL 1 DAY + cal_date END), '$format') as cal_date_end,
                        HOUR(cal_date) as cal_hour,
                        MINUTE(cal_date) as cal_minute,
                        HOUR(cal_time_end) as cal_hour_end,
                        MINUTE(cal_time_end) as cal_minute_end,
                        cal_interval,
                        cal_interval_units,
                        cal_repeat
                    FROM " . MYCALENDAR_TABLE . "
                   WHERE topic_id = $topic_id";
            if (!$results = $db->sql_query($sql)) {
                    message_die(GENERAL_ERROR, 'Failure when looking up previous date entry for editing topic');
            }
            $row = $db->sql_fetchrow($results);
            $cal_data = mycal_validate_data($row);
    } else {
        $cal_data = mycal_validate_data($HTTP_POST_VARS);
        }

        extract($cal_data, EXTR_OVERWRITE);

        // generate a list of months for the current language so javascript can pass it up to the calendar
        $localizedMonthList = array();
        for ($i = 1; $i <= 12; $i++) {
            $month = date("F", mktime (0,0,0,$i,1,00));
            $localizedMonthList[] = '\'' . $lang['datetime'][$month] . '\'';
        }
        $localizedMonthList = implode(',', $localizedMonthList);

        // generate a list of weekdays for the current language so javascript can pass it up to the calendar
        $localizedWeekdayList = array();
        for ($i = 1; $i <= 8; $i++) {
            $weekday = date("l", mktime (0,0,0,10,$i,00));
            $localizedWeekdayList[] = '\'' . strtoupper(substr($lang['datetime'][$weekday], 0, 1)) . '\'';
        }
        $localizedWeekdayList = implode(',', $localizedWeekdayList);

        $interval_units = array(
            'DAY'   => mycal_pluralize($lang['interval']['day'], $lang['interval']['days']),
            'WEEK'  => mycal_pluralize($lang['interval']['week'], $lang['interval']['weeks']),
            'MONTH' => mycal_pluralize($lang['interval']['month'], $lang['interval']['months']),
            'YEAR'  => mycal_pluralize($lang['interval']['year'], $lang['interval']['years']),
        );
        $interval_unit_options = '';
        foreach($interval_units as $unit => $name) {
            $interval_unit_options .= '<option value="' . $unit . '"';
            if ($cal_interval_units == $unit) {
                $interval_unit_options .= ' selected="selected"';
            }
            $interval_unit_options .= '>' . $name . '</option>';
        }

        $template->set_filenames(array(
        'mycalform' => 'posting_mycalendar_form.tpl')
        );

        $template->assign_block_vars('switch_cal_form', array());
        $template->assign_vars(array(
            'L_CALENDAR_EVENT'          => $lang['Calendar_event_title'],
            'L_EVENT_START'             => $lang['Event_Start'],
            'L_EVENT_END'               => $lang['Event_End'],
            'L_CALENDAR_ADVANCED'       => $lang['Calendar_advanced_form'],
            'L_CALENDAR_ADVANCED'       => $lang['Calendar_advanced_form'],
            'L_SELECT_START_DATE'       => $lang['Select_start_date'],
            'L_CLEAR_DATE'              => $lang['Clear_Date'],
            'L_CAL_REPEAT_FOREVER'      => $lang['Calendar_repeat_forever'],
            'CAL_DATE'                  => $cal_date,
            'CAL_DATE_END'              => $cal_date_end,
        	'CAL_HOUR_SELECT'       	=> mycal_make_dropdown(0, 23, $cal_hour),
        	'CAL_MINUTE_SELECT'     	=> mycal_make_dropdown(0, 55, $cal_minute, 5),
        	'CAL_HOUR_END_SELECT'       => mycal_make_dropdown(0, 23, $cal_hour_end),
			'CAL_MINUTE_END_SELECT'     => mycal_make_dropdown(0, 55, $cal_minute_end, 5),
            'CAL_ADVANCED_FORM'         => ($cal_date_end != $lang['Date_not_specified'] || $cal_repeat_always || $cal_hour_end > 0 || $cal_minute_end > 0) ? '' : 'none',
            'CAL_ADVANCED_FORM_ON'      => ($cal_date_end != $lang['Date_not_specified'] || $cal_repeat_always || $cal_hour_end > 0 || $cal_minute_end > 0) ? 'checked="checked"' : '',
            'CAL_NO_DATE'               => $lang['Date_not_specified'],
            'CAL_INTERVAL'              => $cal_interval,
            'CAL_INTERVAL_UNIT_OPTIONS' => $interval_unit_options,
            'CAL_REPEAT_ALWAYS'         => $cal_repeat_always,
            'CAL_DATE_FORMAT'           => $lang['DATE_INPUT_FORMAT'],
            'CAL_START_MONDAY'          => $lang['Calendar_start_monday'] ? 'true' : 'false',
            'CAL_MONTH_LIST'            => $localizedMonthList,
            'CAL_WEEKDAY_LIST'          => $localizedWeekdayList,
            'DATE_SELECTOR_TITLE'       => $lang['Date_selector'],
            'CAL_NEXT_YEAR'             => $lang['View_next_year'],
            'CAL_PREVIOUS_YEAR'         => $lang['View_previous_year'],
            'CAL_NEXT_MONTH'            => $lang['View_next_month'],
            'CAL_PREVIOUS_MONTH'        => $lang['View_previous_month'],
    ));
    $template->assign_var_from_handle('MYCALBOX', 'mycalform');
        $template->set_filenames(array(
        'mycaljs' => 'posting_mycalendar_js.tpl')
    );
    $template->assign_var_from_handle('MYCALJS', 'mycaljs');

}

function mycal_validate_data($selection)
{
    global $lang;
    $cal_repeat_always = !empty($selection['cal_repeat_always']) || (isset($selection['cal_repeat']) && $selection['cal_repeat'] === '0') ? 'checked="checked"' : '';
        $cal_date = isset($selection['cal_date']) ? $selection['cal_date'] : $lang['Date_not_specified'];
        $cal_hour = isset($selection['cal_hour']) ? $selection['cal_hour'] : '00';
        $cal_minute = isset($selection['cal_minute']) ? $selection['cal_minute'] : '00';
        $cal_date_end = isset($selection['cal_date_end']) && empty($cal_repeat_always) ? $selection['cal_date_end'] : $lang['Date_not_specified'];
        $cal_hour_end = isset($selection['cal_hour_end']) ? $selection['cal_hour_end'] : '00';
        $cal_minute_end = isset($selection['cal_minute_end']) ? $selection['cal_minute_end'] : '00';
        $cal_interval = isset($selection['cal_interval']) && (!empty($cal_repeat_always) || $cal_date_end != $lang['Date_not_specified']) ? abs($selection['cal_interval']) : 1;
        $cal_interval_units = isset($selection['cal_interval_units']) && (!empty($cal_repeat_always) || $cal_date_end != $lang['Date_not_specified']) ? $selection['cal_interval_units'] : 'DAY';

        $ts_date = mycal_date2ts($cal_date, $cal_hour, $cal_minute);
        $ts_date_end = mycal_date2ts($cal_date_end, $cal_hour_end, $cal_minute_end);

        if ($ts_date_end === -1) {
        if ($ts_date === -1) {
            $cal_date = $lang['Date_not_specified'];
            $cal_date_end = $lang['Date_not_specified'];
            $cal_hour = '00';
            $cal_hour_end = '00';
            $cal_minute = '00';
            $cal_minute_end = '00';
            $cal_repeat_always = '';
            $cal_interval = 1;
            $cal_interval_units = 'DAY';
        } else {
            $cal_date_end = $cal_date;
            $ts_date_end = mycal_date2ts($cal_date_end, $cal_hour_end, $cal_minute_end);
        }
        } elseif ($ts_date === -1) {
        $cal_date = $cal_date_end;
        $ts_date = mycal_date2ts($cal_date, $cal_hour, $cal_minute);
        }

        if ($cal_date_end != $lang['Date_not_specified'] && $ts_date_end < $ts_date) {
        $tmp = $cal_date;
        $cal_date = $cal_date_end;
        $cal_date_end = $tmp;
        $tmp = $ts_date;
        $ts_date = $ts_date_end;
        $ts_date_end = $tmp;
        if ($cal_hour_end + $cal_minute_end > 0) {
            $tmp = $cal_hour;
            $cal_hour = $cal_hour_end;
            $cal_hour_end = $tmp;
            $tmp = $cal_minute;
            $cal_minute = $cal_minute_end;
            $cal_minute_end = $tmp;
        }
    }

        if ($ts_date_end == $ts_date) {
        $cal_date_end = $lang['Date_not_specified'];
        $cal_repeat = 1;
        $cal_hour_end = '00';
        $cal_minute_end = '00';
        } elseif ($cal_date == $cal_date_end) {
        $cal_date_end = $lang['Date_not_specified'];
        }

    if ($cal_hour + $cal_minute == 0) {
        $cal_hour_end = '00';
        $cal_minute_end = '00';
    }

    $cal_repeat = !empty($cal_repeat_always) ? 0 : 1;

    if ($ts_date_end != -1) {
        $format = str_replace('y', 'Y', strtolower($lang['DATE_INPUT_FORMAT']));
        $date = getdate($ts_date);
        $ts_date = mktime(0,0,0,$date['mon'],$date['mday'],$date['year']);
        $date_end = getdate($ts_date_end);
        $ts_date_end = mktime(0,0,0,$date_end['mon'],$date_end['mday'],$date_end['year']);

        if ($ts_date_end - $ts_date > 0 && $cal_repeat == 1) {
            switch ($cal_interval_units) {
                CASE 'DAY':
                    $cal_repeat = floor(ceil(($ts_date_end - $ts_date) / 86400) / $cal_interval) +1;
                    $ts_date_end = mktime(0,0,0,$date['mon'],$date['mday'] + $cal_interval * ($cal_repeat - 1),$date['year']);
                    break;
                CASE 'WEEK':
                    $cal_repeat = floor(ceil(($ts_date_end - $ts_date) / 86400) / ($cal_interval * 7)) +1;
                    $ts_date_end = mktime(0,0,0,$date['mon'],$date['mday'] + $cal_interval * 7 * ($cal_repeat - 1),$date['year']);
                    break;
                CASE 'MONTH':
                    $day_diff = $date_end['mday'] < $date['mday'] ? -1 : 0;
                    $cal_repeat = ($date_end['year'] - $date['year']) * 12 + $date_end['mon'] - $date['mon'] + $day_diff;
                    $cal_repeat = floor($cal_repeat / $cal_interval) + 1;
                    $ts_date_end = mktime(0,0,0,$date['mon'] + $cal_interval * ($cal_repeat - 1),$date['mday'],$date['year']);
                    break;
                CASE 'YEAR':
                    $day_diff = ($date_end['mon'] < $date['mon'] || ($date_end['mon'] == $date['mon'] && $date_end['mday'] < $date['mday'])) ? -1 : 0;
                    $cal_repeat = floor(($date_end['year'] - $date['year'] + $day_diff) / $cal_interval) + 1;
                    $ts_date_end = mktime(0,0,0,$date['mon'],$date['mday'],$date['year'] + $cal_interval * ($cal_repeat - 1));
                    break;
            }
            $cal_date_end = date($format, $ts_date_end);
        }
    }

    $ts_date += $cal_hour * 3600 + $cal_minute * 60;
    $ts_date_end += $cal_hour_end * 3600 + $cal_minute_end * 60;

    if ($cal_repeat == 1) {
        $cal_date_end = $lang['Date_not_specified'];
        $cal_interval = 1;
        $cal_interval_units = 'DAY';
    }

    $return_array = array ("ts_date", "ts_date_end", "cal_date", "cal_date_end", "cal_hour", "cal_hour_end", "cal_minute", "cal_minute_end",
                "cal_repeat", "cal_repeat_always", "cal_interval", "cal_interval_units");
    return compact($return_array);

}

/**
 * Do a conversion from 01/01/2000 to the unix timestamp
 *
 * Convert from the date used in the form to a unix timestamp, but
 * do it based on the user preference for date formats
 *
 * @param  string date (all numbers < 10 must be '0' padded at this point)
 *
 * @access public
 * @return int unix timestamp
 */
function mycal_date2ts($in_stringDate, $hour='00', $minute='00')
{
    global $lang;

    if ($in_stringDate == $lang['Date_not_specified']) {
        return -1;
    }

    // find the first punctuation character, which will be our delimiter
    $tmp_format = str_replace('y', 'yyyy', str_replace('m', 'mm', str_replace('d', 'dd', strtolower($lang['DATE_INPUT_FORMAT']))));
    $tmp_yOffset = strpos($tmp_format, 'y');
    $tmp_mOffset = strpos($tmp_format, 'm');
    $tmp_dOffset = strpos($tmp_format, 'd');

    // remap the parts to variables, at this point we assume it is coming through the wire 0 padded
    $year  = substr($in_stringDate, $tmp_yOffset, 4);
    $month = substr($in_stringDate, $tmp_mOffset, 2);
    $day   = substr($in_stringDate, $tmp_dOffset, 2);
    return mktime($hour, $minute, 0, $month, $day, $year);
}

/**
 * Universal single/plural option generator
 *
 * This function will take a singular word and its plural counterpart and will
 * combine them by either appending a (s) to the singular word if the plural word
 * is formed this way, or will slash separate the singular and plural words.
 * Example: week(s), country/countries
 *
 * @param string $in_singular singular word
 * @param string $in_plural plural word
 *
 * @access public
 * @author moonbase
 * @return string combined singular/plural contruct
 */
function mycal_pluralize($in_singular, $in_plural)
{
    if ( stristr($in_plural, $in_singular) )
    {
        return substr($in_plural, 0, strlen($in_singular)) . ((strlen($in_plural) > strlen($in_singular)) ? '(' . substr($in_plural, strlen($in_singular)) . ')' : '');
    }

    return $in_singular . '/' . $in_plural;
}


function mycal_format_span($ts_date, $ts_date_end = '', $date_format = '', $time_format = '')
{
    global $lang, $board_config;

    $date_offset = date('Z',$ts_date) / 3600;
    $date_end_offset = date('Z',$ts_date_end) / 3600;


    if (empty($date_format)) $date_format = $lang['DATE_FORMAT'];
    if (empty($time_format)) $time_format = $lang['TIME_FORMAT'];
    if (empty($ts_date_end)) {
        $ts_date_end = $ts_date;
        $single = TRUE;
    }

    if (!$single) {
        $date_year = date('Y', $ts_date);
        $date_year_end = date('Y', $ts_date_end);
        if ( $date_year == $date_year_end && $date_year == date('Y') ) $date_format = preg_replace("/[Yy][\-\/\.\s]?/",'',$date_format);
    }

    $date = create_date($date_format, $ts_date, $date_offset);
    $time = date('H:i', $ts_date) != '00:00' ? create_date(" $time_format", $ts_date, $date_offset) : '';
    $time_end = ( date('H:i', $ts_date_end) != '00:00' && !$single) ? create_date(" $time_format", $ts_date_end, $date_end_offset) : '';

    if ( !$single && date('Ymd', $ts_date_end) < date('Ymd', $ts_date)) {
        $open = $lang['open_end'];
        $date_end = $date;
    } else {
        $date_end = create_date($date_format, $ts_date_end, $date_end_offset);
    }

    if ($date_end == $date || $single) $date_end = '';
    $connector = (!empty($date_end) || !empty($time_end)) ? ' - ' : '';
    $full_date = $date . $time . $connector . $date_end . $time_end . " $open";
    return $full_date;
}

function mycal_repeattext($unit, $interval)
{
    global $lang;
    $unit = strtolower($unit);
    if ($interval > 1 && isset($lang['interval'][$unit . 's'])) {
        $repeat = "<b>" . $lang['repeat'] . ": </b>" . sprintf($lang['repeat_interval'], $interval, $lang['interval'][$unit . 's']);
    } elseif ($interval == 1 && isset($lang['interval'][$unit . 'ly'])) {
        $repeat = "<b>" . $lang['repeat'] . ": </b>" . $lang['interval'][$unit . 'ly'];
    } else return;

    return $repeat;
}

function mycal_move_event($type, $new_forum_id, $topic_id, $leave_shadow = false)
{
    global $db;
    $where = $type == 'forum' ? "forum_id = $topic_id" : "topic_id IN ($topic_id)";
    // if we are not leaving a shadow and the new forum doesn't do events,
    // then delete to event and return
    if (!$leave_shadow && $type != 'forum') {
    mycal_delete_event($topic_id, null, false);
        return;
    } else {
        $sql = "UPDATE " . MYCALENDAR_TABLE . " SET forum_id = $new_forum_id, cal_date = cal_date WHERE $where";
        if (!$db->sql_query($sql)) {
            message_die(GENERAL_MESSAGE, 'Could not relocate the event.');
        }
    }
}

/**
 * Remove an event from the mycalendar table
 *
 * When a topic is removed, and not just a reply within that topic,
 * the event is deleted from the mycalendar table appropriately.
 *
 * @param  mixed  $topic_id either int or comma seperated..if $check_post is false, it must be int
 * @param  int  $post_id
 * @param  bool $check_post verify that the post is the first post and not a reply
 *
 * @access public
 * @return void
 */
function mycal_delete_event($topic_id, $post_id, $check_post = false)
{
    global $db;

    // First we must verify that this we are deleting a whole topic...not
    // just a single post within the topic
    // we have to use two queries for old databases, even though MySQL can do it in one
    if ($check_post) {
        $sql = "SELECT c.cal_id FROM " . MYCALENDAR_TABLE . " as c, " . TOPICS_TABLE . " as t
                WHERE t.topic_id = $topic_id AND c.topic_id = $topic_id AND t.topic_first_post_id = $post_id";
        if (!$result = $db->sql_query($sql)) {
            message_die(GENERAL_MESSAGE, 'Error in query which determines if post is leading post in topic.');
        }
    }

    $where = $post_id == -1 ? "forum_id = $topic_id" : "topic_id IN ($topic_id)";

    if (!$check_post || $db->sql_numrows($result) > 0) {
        $sql = "DELETE FROM " . MYCALENDAR_TABLE . " WHERE $where";
        if (!$db->sql_query($sql)) {
            message_die(GENERAL_MESSAGE, 'Could not delete event.');
        }
    }
}

function mycal_get_forumstyle()
{
    global $db;

    $forumstyle = array();
    $sql = "SELECT * FROM " . CONFIG_TABLE . " WHERE config_name LIKE 'mycal_%'";
    if(!$result = $db->sql_query($sql))
    {
        message_die(CRITICAL_ERROR, "Could not query mycalendar config infod", "", __LINE__, __FILE__, $sql);
    } else {
        while( $row = $db->sql_fetchrow($result) ) {
            $style_forum_id = substr($row['config_name'], 0, 17) == "mycal_forumstyle_" ? substr($row['config_name'],17) : '';
            if ($style_forum_id) $forumstyle[$style_forum_id] = $row['config_value'];
        }
    }

    return $forumstyle;
}

?>